@@ -6,7 +6,7 @@ use JSON::PP ();
 use File::Spec;
 use File::ShareDir ();
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 NAME
 
@@ -63,7 +63,11 @@ The compiler flags for compiling against C<libpkgconf>.
 
 sub cflags
 {
-  _config->{cflags};
+  my($class) = @_;
+  $class->install_type eq 'share'
+  # may induce duplicates :/
+  ? "-I@{[ _dist_dir 'include', 'pkgconf' ]} @{[ _config->{cflags} ]}"
+  : _config->{cflags};
 }
 
 =head2 libs
@@ -76,7 +80,11 @@ The linker flags for linking against C<libpkgconf>.
 
 sub libs
 {
-  _config->{libs};
+  my($class) = @_;
+  $class->install_type eq 'share'
+  # may induce duplicates :/
+  ? "-L@{[ _dist_dir 'lib' ]} @{[ _config->{libs} ]}"
+  : _config->{libs};
 }
 
 =head2 dynamic_libs
